<a id="mypy-boto3-application-autoscaling"></a>

# mypy-boto3-application-autoscaling

[![PyPI - types-aiobotocore-application-autoscaling](https://img.shields.io/pypi/v/types-aiobotocore-application-autoscaling.svg?color=blue)](https://pypi.org/project/types-aiobotocore-application-autoscaling)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-application-autoscaling.svg?color=blue)](https://pypi.org/project/types-aiobotocore-application-autoscaling)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-application-autoscaling?color=blue)](https://pypistats.org/packages/types-aiobotocore-application-autoscaling)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.ApplicationAutoScaling 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/application-autoscaling.html#ApplicationAutoScaling)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-application-autoscaling docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_application_autoscaling/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-application-autoscaling](#mypy-boto3-application-autoscaling)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ApplicationAutoScaling`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ApplicationAutoScaling` service.

```bash
python -m pip install types-aiobotocore[application-autoscaling]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[application-autoscaling]` in your environment:
  `python -m pip install 'types-aiobotocore[application-autoscaling]'`

Both type checking and auto-complete should work for `ApplicationAutoScaling`
service. No explicit type annotations required, write your `boto3` code as
usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[application-autoscaling]` in your environment:
  `python -m pip install 'types-aiobotocore[application-autoscaling]'`

Both type checking and auto-complete should work for `ApplicationAutoScaling`
service. No explicit type annotations required, write your `aiobotocore` code
as usual. Auto-complete can be slow on big projects or if you have a lot of
installed `types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[application-autoscaling]` in your environment:
  `python -m pip install 'types-aiobotocore[application-autoscaling]'`
- Run `mypy` as usual

Type checking should work for `ApplicationAutoScaling` service. No explicit
type annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[application-autoscaling]` in your environment:
  `python -m pip install 'types-aiobotocore[application-autoscaling]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ApplicationAutoScaling` service. No explicit
type annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ApplicationAutoScalingClient` provides annotations for
`session.create_client("application-autoscaling")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_application_autoscaling import ApplicationAutoScalingClient

session = get_session()
with async session.create_client("application-autoscaling") as client:
    client: ApplicationAutoScalingClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_application_autoscaling.paginator` module contains type
annotations for all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_application_autoscaling import ApplicationAutoScalingClient
from types_aiobotocore_application_autoscaling.paginator import (
    DescribeScalableTargetsPaginator,
    DescribeScalingActivitiesPaginator,
    DescribeScalingPoliciesPaginator,
    DescribeScheduledActionsPaginator,
)

session = get_session()
with async session.create_client("application-autoscaling") as client:
    client: ApplicationAutoScalingClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_scalable_targets_paginator: DescribeScalableTargetsPaginator = client.get_paginator("describe_scalable_targets")
        describe_scaling_activities_paginator: DescribeScalingActivitiesPaginator = client.get_paginator("describe_scaling_activities")
        describe_scaling_policies_paginator: DescribeScalingPoliciesPaginator = client.get_paginator("describe_scaling_policies")
        describe_scheduled_actions_paginator: DescribeScheduledActionsPaginator = client.get_paginator("describe_scheduled_actions")
    ```







### Literals

`types_aiobotocore_application_autoscaling.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_application_autoscaling.literals import (
    AdjustmentTypeType,
    DescribeScalableTargetsPaginatorName,
    DescribeScalingActivitiesPaginatorName,
    DescribeScalingPoliciesPaginatorName,
    DescribeScheduledActionsPaginatorName,
    MetricAggregationTypeType,
    MetricStatisticType,
    MetricTypeType,
    PolicyTypeType,
    ScalableDimensionType,
    ScalingActivityStatusCodeType,
    ServiceNamespaceType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AdjustmentTypeType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_application_autoscaling.type_defs` module contains
structures and shapes assembled to typed dictionaries for additional type
checking.

```python
from types_aiobotocore_application_autoscaling.type_defs import (
    AlarmTypeDef,
    CustomizedMetricSpecificationTypeDef,
    DeleteScalingPolicyRequestRequestTypeDef,
    DeleteScheduledActionRequestRequestTypeDef,
    DeregisterScalableTargetRequestRequestTypeDef,
    DescribeScalableTargetsRequestRequestTypeDef,
    DescribeScalableTargetsResponseTypeDef,
    DescribeScalingActivitiesRequestRequestTypeDef,
    DescribeScalingActivitiesResponseTypeDef,
    DescribeScalingPoliciesRequestRequestTypeDef,
    DescribeScalingPoliciesResponseTypeDef,
    DescribeScheduledActionsRequestRequestTypeDef,
    DescribeScheduledActionsResponseTypeDef,
    MetricDimensionTypeDef,
    PaginatorConfigTypeDef,
    PredefinedMetricSpecificationTypeDef,
    PutScalingPolicyRequestRequestTypeDef,
    PutScalingPolicyResponseTypeDef,
    PutScheduledActionRequestRequestTypeDef,
    RegisterScalableTargetRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    ScalableTargetActionTypeDef,
    ScalableTargetTypeDef,
    ScalingActivityTypeDef,
    ScalingPolicyTypeDef,
    ScheduledActionTypeDef,
    StepAdjustmentTypeDef,
    StepScalingPolicyConfigurationTypeDef,
    SuspendedStateTypeDef,
    TargetTrackingScalingPolicyConfigurationTypeDef,
)

def get_structure() -> AlarmTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-application-autoscaling` version is the same as related
`boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-application-autoscaling docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_application_autoscaling/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
